Tutorial
=========

This tutorial walks you through building a wine catalogue API with **Flask-Jeroboam**. We focus on Jeroboam specifics and assume some Flask familiarity. If you're new to Flask, the `Flask Tutorial <https://flask.palletsprojects.com/en/2.2.x/tutorial/>`_ is excellent.

.. _Flask Tutorial: https://flask.palletsprojects.com/en/2.2.x/tutorial/

.. toctree::
    :caption: Contents:
    :maxdepth: 1

    setting_things_up
    first_api


Other Ressources
----------------

- Michael Grinberg's `Mega Tutorial <https://blog.miguelgrinberg.com/post/the-flask-mega-tutorial-part-i-hello-world>`_ is a must read. It's a great introduction to Flask and covers a lot of ground.
- `FastAPI Documentation <https://fastapi.tiangolo.com/>`_ is in my opinion a gold standard. It's very well written, and thorough and the examples are easy to follow. You should definitely check it out. It holds value even if you're not going to use FastAPI.
